summaryrefslogtreecommitdiffstats
path: root/net/flip/flip_network_transaction_unittest.cc
diff options
context:
space:
mode:
Diffstat (limited to 'net/flip/flip_network_transaction_unittest.cc')
-rw-r--r--net/flip/flip_network_transaction_unittest.cc42
1 files changed, 24 insertions, 18 deletions
diff --git a/net/flip/flip_network_transaction_unittest.cc b/net/flip/flip_network_transaction_unittest.cc
index 84e0e78..4f41063 100644
--- a/net/flip/flip_network_transaction_unittest.cc
+++ b/net/flip/flip_network_transaction_unittest.cc
@@ -147,15 +147,18 @@ TEST_F(FlipNetworkTransactionTest, Constructor) {
TEST_F(FlipNetworkTransactionTest, Get) {
static const unsigned char syn[] = {
0x80, 0x01, 0x00, 0x01, // header
- 0x01, 0x00, 0x00, 0x30, // FIN, len
+ 0x01, 0x00, 0x00, 0x46, // FIN, len
0x00, 0x00, 0x00, 0x01, // stream id
- 0xc0, 0x00, 0x00, 0x03, // 4 headers
- 0x00, 0x06, 'm', 'e', 't', 'h', 'o', 'd', // "hello"
- 0x00, 0x03, 'G', 'E', 'T', // "bye"
- 0x00, 0x03, 'u', 'r', 'l', // "url"
- 0x00, 0x01, '/', // "/"
- 0x00, 0x07, 'v', 'e', 'r', 's', 'i', 'o', 'n', // "status"
- 0x00, 0x08, 'H', 'T', 'T', 'P', '/', '1', '.', '1', // "200"
+ 0xc0, 0x00, 0x00, 0x04, // 4 headers
+ 0x00, 0x04, 'h', 'o', 's', 't',
+ 0x00, 0x0e, 'w', 'w', 'w', '.', 'g', 'o', 'o', 'g', 'l', 'e',
+ '.', 'c', 'o', 'm',
+ 0x00, 0x06, 'm', 'e', 't', 'h', 'o', 'd',
+ 0x00, 0x03, 'G', 'E', 'T',
+ 0x00, 0x03, 'u', 'r', 'l',
+ 0x00, 0x01, '/',
+ 0x00, 0x07, 'v', 'e', 'r', 's', 'i', 'o', 'n',
+ 0x00, 0x08, 'H', 'T', 'T', 'P', '/', '1', '.', '1',
};
static const unsigned char syn_reply[] = {
@@ -221,16 +224,19 @@ TEST_F(FlipNetworkTransactionTest, Post) {
// TODO(mbelshe): Hook up the write validation.
//static const unsigned char syn[] = {
// 0x80, 0x01, 0x00, 0x01, // header
// 0x00, 0x00, 0x00, 0x30, // FIN, len
// 0x00, 0x00, 0x00, 0x01, // stream id
// 0xc0, 0x00, 0x00, 0x03, // 4 headers
// 0x00, 0x06, 'm', 'e', 't', 'h', 'o', 'd', // "hello"
// 0x00, 0x03, 'G', 'E', 'T', // "bye"
// 0x00, 0x03, 'u', 'r', 'l', // "url"
// 0x00, 0x01, '/', // "/"
// 0x00, 0x07, 'v', 'e', 'r', 's', 'i', 'o', 'n', // "status"
// 0x00, 0x08, 'H', 'T', 'T', 'P', '/', '1', '.', '1', // "200"
//};
//static const unsigned char upload_frame[] = {
@@ -221,16 +224,19 @@ TEST_F(FlipNetworkTransactionTest, Post) {
// TODO(mbelshe): Hook up the write validation.
//static const unsigned char syn[] = {
- // 0x80, 0x01, 0x00, 0x01, // header
- // 0x00, 0x00, 0x00, 0x30, // FIN, len
- // 0x00, 0x00, 0x00, 0x01, // stream id
- // 0xc0, 0x00, 0x00, 0x03, // 4 headers
- // 0x00, 0x06, 'm', 'e', 't', 'h', 'o', 'd', // "hello"
- // 0x00, 0x03, 'G', 'E', 'T', // "bye"
- // 0x00, 0x03, 'u', 'r', 'l', // "url"
- // 0x00, 0x01, '/', // "/"
- // 0x00, 0x07, 'v', 'e', 'r', 's', 'i', 'o', 'n', // "status"
- // 0x00, 0x08, 'H', 'T', 'T', 'P', '/', '1', '.', '1', // "200"
+ // 0x80, 0x01, 0x00, 0x01, // header
+ // 0x01, 0x00, 0x00, 0x46, // FIN, len
+ // 0x00, 0x00, 0x00, 0x01, // stream id
+ // 0xc0, 0x00, 0x00, 0x04, // 4 headers
+ // 0x00, 0x04, 'h', 'o', 's', 't',
+ // 0x00, 0x0e, 'w', 'w', 'w', '.', 'g', 'o', 'o', 'g', 'l', 'e',
+ // '.', 'c', 'o', 'm',
+ // 0x00, 0x06, 'm', 'e', 't', 'h', 'o', 'd',
+ // 0x00, 0x03, 'G', 'E', 'T',
+ // 0x00, 0x03, 'u', 'r', 'l',
+ // 0x00, 0x01, '/',
+ // 0x00, 0x07, 'v', 'e', 'r', 's', 'i', 'o', 'n',
+ // 0x00, 0x08, 'H', 'T', 'T', 'P', '/', '1', '.', '1',
//};
//static const unsigned char upload_frame[] = {